@@ -296,10 +296,10 @@ class CameraCtrlsWindow(Gtk.ApplicationWindow):
         self.frame.attach(stack_box, 0, 1, 1, 1)
         self.stack = stack
 
-        for page in self.camera.get_ctrl_pages():
+        for page_n, page in enumerate(self.camera.get_ctrl_pages()):
             page_box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
             if page.target == 'main':
-                stack.add_titled(page_box, page.title.lower(), page.title)
+                stack.add_titled(page_box, str(page_n), page.title)
             elif page.target == 'footer':
                 sep = Gtk.Separator(margin_bottom=10)
                 footer.append(sep)
@@ -386,9 +386,23 @@ class CameraCtrlsWindow(Gtk.ApplicationWindow):
                         refresh = Gtk.Button(icon_name='edit-undo-symbolic', valign=Gtk.Align.CENTER, halign=Gtk.Align.START, has_frame=False)
                         refresh.connect('clicked', lambda e, c=c, sc=scale: sc.get_adjustment().set_value(c.default))
                         ctrl_box.append(refresh)
-                        ctrl_box.append(scale)
+                        scale_stack = Gtk.Stack(transition_type=Gtk.StackTransitionType.SLIDE_LEFT_RIGHT, transition_duration=500)
+                        scale_box = Gtk.Box(halign=Gtk.Align.END)
+                        spin_box = Gtk.Box(halign=Gtk.Align.END)
+                        prev_button = Gtk.Button(icon_name='go-previous-symbolic', has_frame=False, opacity=0.2)
+                        prev_button.connect('clicked', lambda e, st=scale_stack, sc=scale_box: st.set_visible_child(sc))
+                        next_button = Gtk.Button(icon_name='go-next-symbolic', has_frame=False, opacity=0.2)
+                        next_button.connect('clicked', lambda e, st=scale_stack, sp=spin_box: st.set_visible_child(sp))
+                        scale_box.append(scale)
+                        scale_box.append(next_button)
+                        spin = Gtk.SpinButton(adjustment=scale.get_adjustment())
+                        spin_box.append(spin)
+                        spin_box.append(prev_button)
+                        scale_stack.add_child(scale_box)
+                        scale_stack.add_child(spin_box)
+                        ctrl_box.append(scale_stack)
                         c.gui_value_set = scale.set_value
-                        c.gui_ctrls += [scale, refresh]
+                        c.gui_ctrls += [scale, spin, refresh]
                         c.gui_default_btn = refresh
 
                     elif c.type == 'boolean':
@@ -428,9 +442,6 @@ class CameraCtrlsWindow(Gtk.ApplicationWindow):
                                     self.update_ctrl(c, m.lp_text_id)
                                 ])
                                 b.add_controller(lp)
-                            if m.use_shortcut:
-                                b.set_label('_' + m.name)
-                                b.set_use_underline(True)
                             box.append(b)
                             c.gui_ctrls += b
                         if c.default is not None:
@@ -678,7 +689,18 @@ class CameraCtrlsApp(Gtk.Application):
         action.connect('activate', self.on_quit)
         self.add_action(action)
 
-        self.set_accels_for_action('app.quit',["<Primary>Q"])
+        action = Gio.SimpleAction.new('alt_n', GLib.VariantType('i'))
+        action.connect('activate', self.on_alt_n)
+        self.add_action(action)
+
+        self.set_accels_for_action('app.quit', ["<Primary>Q"])
+        self.set_accels_for_action('app.alt_n(0)', ["<Alt>1"])
+        self.set_accels_for_action('app.alt_n(1)', ["<Alt>2"])
+        self.set_accels_for_action('app.alt_n(2)', ["<Alt>3"])
+        self.set_accels_for_action('app.alt_n(3)', ["<Alt>4"])
+        self.set_accels_for_action('app.alt_n(4)', ["<Alt>5"])
+        self.set_accels_for_action('app.alt_n(5)', ["<Alt>6"])
+        self.set_accels_for_action('app.alt_n(6)', ["<Alt>7"])
 
     def do_activate(self):
         self.window = CameraCtrlsWindow(application=self, title='Cameractrls')
@@ -690,7 +712,7 @@ class CameraCtrlsApp(Gtk.Application):
         about.set_authors(['Gergo Koteles <soyer@irl.hu>'])
         about.set_artists(['Jorge Toledo https://lacajita.es'])
         about.set_copyright('Copyright © 2022 - 2024 Gergo Koteles')
-        about.set_license_type(Gtk.License.GPL_3_0)
+        about.set_license_type(Gtk.License.LGPL_3_0)
         about.set_logo_icon_name('hu.irl.cameractrls')
         about.set_website(ghurl)
         about.set_website_label('GitHub')
@@ -700,6 +722,11 @@ class CameraCtrlsApp(Gtk.Application):
     def on_quit(self, action, param):
         self.window.close()
 
+    def on_alt_n(self, action, param):
+        page_n = str(param)
+        if self.window.stack and self.window.stack.get_child_by_name(page_n):
+            self.window.stack.set_visible_child_name(page_n)
+
     def check_preview_open(self, p):
         # if process returned
         if p.poll() is not None:
